import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import fs from 'fs';
import https from 'https';
import unzipper from 'unzipper';
import rimraf from 'rimraf';
import Queue from 'queue-async';
import { promisify } from 'util';
import replaceString from './replaceString';
export function generateFolderStructure(_options, _callback) {
  var options = _objectSpread({}, _options);

  var repoName = options.type === 'mobile' ? 'fl-base-mobile-app' : 'fl-base-webapp';
  var repoZipUrl = "https://codeload.github.com/founderlab/".concat(repoName, "/zip/master");
  var zipFilename = "".concat(repoName, ".zip");
  var oldFolder = "".concat(repoName, "-master");
  var newFolder = options.name;
  var writer = fs.createWriteStream(zipFilename);
  var replace = [{
    filePath: "".concat(newFolder, "/shared/modules/app/containers/Navbar.js"),
    name: options.name
  }, {
    filePath: "".concat(newFolder, "/package.json"),
    name: options.name
  }, {
    filePath: "".concat(newFolder, "/.env"),
    name: options.name.toLowerCase().replace(/\W/g, '_')
  }];

  function callback(err) {
    var queue = new Queue(); // delete zip

    queue.defer(function (callback) {
      fs.access(zipFilename, fs.F_OK, function (err) {
        if (err) return callback(err);
        fs.unlink(zipFilename, function (err) {
          if (err) return callback(err);
          if (options.verbose) console.log('--Zip deleted.');
          callback(null);
        });
      });
    }); // delete old folder

    queue.defer(function (callback) {
      fs.access(oldFolder, fs.F_OK, function (err) {
        if (err) {
          // err means successfully renamed
          return callback(null);
        } // otherwise delete the old folder


        rimraf(oldFolder, function (err) {
          if (err) return callback(err);
          if (options.verbose) console.log('--Folder ' + oldFolder + ' deleted.');
          callback(new Error('Failed when renaming ' + oldFolder + ' to ' + newFolder + ', ' + newFolder + ' already exists.'));
        });
      });
    });

    if (err && err.message === "String replacement failure: ".concat(err)) {
      // delete new folder
      queue.defer(function (callback) {
        fs.access(newFolder, fs.F_OK, function (err) {
          if (err) return callback(err); // otherwise delete the old folder

          rimraf(newFolder, function (err) {
            if (err) return callback(err);
            if (options.verbose) console.log('--Folder ' + newFolder + ' deleted.');
            callback(new Error('Failed when modifying .env or package.json.'));
          });
        });
      });
    }

    queue["await"](_callback);
  } // download, unzipper, rename


  https.get(repoZipUrl, function (res) {
    res.on('data', function (d) {
      return writer.write(d);
    });
    res.on('end', function () {
      if (options.verbose) console.log('--Zip downloaded.');
      var stream = fs.createReadStream(zipFilename).pipe(unzipper.Extract({
        path: './'
      }));
      stream.on('close', function () {
        if (options.verbose) console.log('--Zip extracted to folder ' + oldFolder + '.');
        fs.rename(oldFolder, newFolder, function (err) {
          if (err) return callback(err);
          if (options.verbose) console.log('--Folder renamed to ' + newFolder + '.');
          var queue = new Queue(); // Set the app name in a few files

          replace.forEach(function (_ref) {
            var filePath = _ref.filePath,
                name = _ref.name;
            queue.defer(function (callback) {
              replaceString(filePath, /FounderLab_replaceme/g, name, function (err) {
                if (err) return callback(err);
                if (options.verbose) console.log('--' + filePath + ' modified.');
                callback();
              });
            });
          });
          queue["await"](callback);
        });
      });
    });
  });
}
export default promisify(generateFolderStructure);