#!/usr/bin/env node
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import program from 'commander';
import chalk from 'chalk';
import fs from 'fs';
import path from 'path';
import createProject from './commands/createProject';
import createModel from './commands/createModel';
import createSchema from './commands/createSchema';

function inCorrectDirectory() {
  return fs.existsSync(path.resolve(process.cwd(), 'client')) && fs.existsSync(path.resolve(process.cwd(), 'server')) && fs.existsSync(path.resolve(process.cwd(), 'shared'));
}

program.version('0.0.1').option('-l, --verbose', 'Show more information when the command is being excecuted').option('-d, --dry_run', 'A dry_run run which will only list the effected records/files').option('-f, --force', 'Force');
program.command('add-model <name>').alias('m').description('Create a new model in the current app').action( /*#__PURE__*/function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(name) {
    var options;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            options = {
              name: name,
              root: process.cwd(),
              force: program.force,
              verbose: program.verbose
            };

            if (!(!options.force && !inCorrectDirectory())) {
              _context.next = 3;
              break;
            }

            return _context.abrupt("return", console.log(chalk.red("This command should be run from the root directory of Frameworkstein web apps")));

          case 3:
            console.log("Creating model ".concat(chalk.blue(name), " with options"), options);
            _context.next = 6;
            return createModel(options);

          case 6:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function (_x) {
    return _ref.apply(this, arguments);
  };
}());
program.command('add-models <filename>').alias('schema').alias('models').description('Generate model files from a graphql schema definition file').action( /*#__PURE__*/function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(filename) {
    var options;
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            options = {
              filename: path.join(process.cwd(), filename),
              root: process.cwd(),
              force: program.force,
              verbose: program.verbose
            };

            if (!(!options.force && !inCorrectDirectory())) {
              _context2.next = 3;
              break;
            }

            return _context2.abrupt("return", console.log(chalk.red("This command should be run from the root directory of Frameworkstein web apps")));

          case 3:
            console.log("Creating models from file ".concat(chalk.green(filename), " with options"), options);
            _context2.next = 6;
            return createSchema(options);

          case 6:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));

  return function (_x2) {
    return _ref2.apply(this, arguments);
  };
}());
program.command('new-web <name>').alias('new').description('Create a new web app').option('-t, --type', 'Type').action( /*#__PURE__*/function () {
  var _ref3 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3(name) {
    var options;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            options = {
              name: name,
              type: 'web',
              root: process.cwd(),
              force: program.force,
              verbose: program.verbose
            };
            console.log("Creating new web app ".concat(chalk.green(name), " with options"), options);
            _context3.next = 4;
            return createProject(options);

          case 4:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  }));

  return function (_x3) {
    return _ref3.apply(this, arguments);
  };
}());
program.command('new-mobile <name>').description('Create a new mobile app').option('-t, --type', 'Type').action( /*#__PURE__*/function () {
  var _ref4 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4(name) {
    var options;
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            options = {
              name: name,
              type: 'mobile',
              root: process.cwd(),
              force: program.force,
              verbose: program.verbose
            };
            console.log("Creating new mobile app ".concat(chalk.green(name), " with options"), options);
            _context4.next = 4;
            return createProject(options);

          case 4:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  }));

  return function (_x4) {
    return _ref4.apply(this, arguments);
  };
}());
program.parse(process.argv);